==> haskell-base-prelude-1.5-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.5
visibility:           public
id:                   base-prelude-1.5-5CcmuqpQ4wa2zQcuG81Oo2
key:                  base-prelude-1.5-5CcmuqpQ4wa2zQcuG81Oo2
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude
synopsis:
    The most complete prelude formed solely from the "base" package

description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  a6fe35b3dc20913e519d8ef8428cf1f0
exposed:              True
exposed-modules:
    BasePrelude BasePrelude.DataTypes BasePrelude.Operators

import-dirs:          /usr/lib/ghc-9.0.2/site-local/base-prelude-1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/base-prelude-1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/base-prelude-1.5
hs-libraries:         HSbase-prelude-1.5-5CcmuqpQ4wa2zQcuG81Oo2
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.6
visibility:           public
id:                   base-prelude-1.6-HwNtHn5fnrh8IggO2P9oPk
key:                  base-prelude-1.6-HwNtHn5fnrh8IggO2P9oPk
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude
synopsis:             Featureful preludes formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.

    This package will never have any dependencies other than \"base\".

    Besides a rich prelude it provides limited ones like "BasePrelude.DataTypes",
    which only exports the data-types defined across the \"base\" package,
    and "BasePrelude.Operators", which only exports the common operators.

    /Versioning policy/

    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  23190f974c4fcfd5f86c79cae1a13b76
exposed:              True
exposed-modules:
    BasePrelude BasePrelude.DataTypes BasePrelude.Operators

import-dirs:          /usr/lib/ghc-9.0.2/site-local/base-prelude-1.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/base-prelude-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/base-prelude-1.6
hs-libraries:         HSbase-prelude-1.6-HwNtHn5fnrh8IggO2P9oPk
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
